<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Account_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();
    if (!isset($_SESSION['xfront_customer'])) redirect(base_url('signin'), 'refresh');

    $this->load->model('account_model');
    $this->load->model('index_model');
  }

  public function index()
  {
    $data['page'] = 'account';
    $data['crumbs'] = ['account'];
    $data['profile'] = $this->account_model->_get();
    if (isset($_SESSION['xfront_customer'])) {
      $data['country'] = $this->account_model->_get_country() ?: "";
      if ($data['country'] == "Nigeria") {
        $data['regions'] = $this->account_model->_get_region('Nigeria') ?: "";
      } else {
        $data['regions'] = $this->account_model->_get_region('England') ?: "";
      }
      $data['debt'] = $this->account_model->_get_debt();
      $data['inbox'] = $this->account_model->_get_inbox();
      $data['items'] = $this->account_model->_get_order_items();
      $data['opens'] = $this->account_model->_get_orders('0');
      $data['closed'] = $this->account_model->_get_orders('1');
      $data['payments'] = $this->account_model->_get_payments();
      $data['addresses'] = $this->account_model->_get_addresses();
      $data['currency'] = $this->index_model->_get_currency() ?: "";
    }
    $this->load->view('shopping', $data);
  }

  function pages($page)
  {
    $uris = ['profile', 'password', 'policy', 'inbox', 'address', 'payment', 'update'];
    if (!in_array($page, $uris)) redirect(base_url());

    $k = $this->input->get('k');
    $token = $this->input->get('token');
    $mode = $this->input->get('mode');

    if ($page == 'update') exit($this->$k($token));
    if ($mode & $token != '') exit($this->$k($token));
    if ($mode) exit($this->$k);

    $this->present($page);
  }
  function delete($token)
  {
    if (!$this->account_model->_drop_address($token));
    json_encode(['status' => 'success', 'message' => 'Address Created']);
    exit(redirect(base_url('account.aspx'), 'refresh'));
  }
  function nAddress()
  {
    $addr = trim($this->input->post('address'));
    $city = trim($this->input->post('city'));
    $cout = trim($this->input->post('country'));
    $zip  = trim($this->input->post('zipcode'));
    if ($addr == '' or $city == '' or $cout == '' or $zip == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!$this->account_model->_new_address([
      'zip' => $zip,
      'city' => $city,
      'address' => $addr,
      'country' => $cout
    ]));
    exit(json_encode(['status' => 'success', 'message' => 'Address Created']));
  }

  function address($token)
  {
    $addr = trim($this->input->post('address'));
    $city = trim($this->input->post('city'));
    $cout = trim($this->input->post('country'));
    $zip  = trim($this->input->post('zipcode'));
    if ($addr == '' or $city == '' or $cout == '' or $zip == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    $this->account_model->_put_address($token, [
      'zip' => $zip,
      'city' => $city,
      'address' => $addr,
      'country' => $cout
    ]);
    // $this->session->set_flashdata('xfront_message', 'Address updated');
    exit(json_encode(['status' => 'success', 'message' => 'Address updated']));
  }

  function present($page, $token = '')
  {
    $this->load->helper('file');
    $this->load->helper('path');
    if (!is_file(APPPATH . "/views/pages/$page.php")) redirect('not_found');
    $data['auth'] = $this->session->userdata('xcel-auth');
    $data['page'] = $page;
    $data['profile'] = $this->account_model->_get();
    $this->load->view('shopping', $data);
  }

  function profile($token = '')
  {
    $name  = trim($this->input->post('names'));
    $email = trim($this->input->post('email'));
    $phone = trim($this->input->post('phone'));
    if ($email == '' or $phone == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) exit(json_encode(['status' => 'error', 'message' => 'Email is invalid']));
    if (!is_numeric($phone) or strlen($phone) < 11 or $phone < 1) exit(json_encode(['status' => 'error', 'message' => 'Phone number is invalid']));
    $this->account_model->_put(['name' => $name, 'email' => $email, 'phone' => $phone]);
    // $this->session->set_flashdata('xfront_message', 'Profile details updated');
    exit(json_encode(['status' => 'success', 'message' => 'Profile details updated']));
  }

  function password($token = '')
  {
    $opa = $this->input->post('opass');
    $npa = $this->input->post('npass');
    $cpa = $this->input->post('cpass');

    if ($npa == null or $cpa == null or $opa == null)
      exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if ($npa != $cpa) exit(json_encode(['status' => 'error', 'message' => 'New Passwords do not match']));
    if (!ctype_alnum($npa) or strlen($npa) < 8)
      exit(json_encode(['status' => 'error', 'message' => 'Passwords can be alphabets and numbers <br />and not less than 8 characters long']));

    $user = $this->account_model->_get(['token' => $_SESSION['xfront_customer']]);
    if (!$user or !password_verify("GG$opa", $user['password']))
      exit(json_encode(['status' => 'error', 'message' => 'Old password is incorrect']));

    $this->account_model->_put(['password' => password_hash("GG$npa", PASSWORD_DEFAULT)]);
    $this->session->set_flashdata('xfront_message', 'Password updated');
    exit(json_encode(['status' => 'success', 'message' => '']));
  }
}
