<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Account_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();
  }

  function _get()
  {
    if (!isset($_SESSION['xfront_customer'])) return [];
    $user = $this->db->get_where('er_customers', ['token' => $_SESSION['xfront_customer']]);
    if (!$user->num_rows() > 0) return [];
    return $user->row_array();
  }


  function _get_addresses()
  {
    if (!isset($_SESSION['xfront_customer'])) return [];
    $user = $this->db->get_where('er_addresses', [
      'user' => $_SESSION['xfront_customer'],
      'status' => 0
    ]);
    if (!$user->num_rows() > 0) return [];
    return $user->result_array();
  }

  function _get_item($token)
  {
    $extract = "CAST(JSON_EXTRACT(`price`, '$.a577f519b58b533e400cf28a7464576babf92121[0]') AS DECIMAL(10,1))";
    $this->db->select("*, $extract AS price");
    $item = $this->db->get_where('er_online_warehouse', ['status' => 0, 'token' => $token]);
    if (!$item) return false;
    return $item->row();
  }

  function _get_orders($status)
  {
    $this->db->order_by('created_at DESC');
    $orders = $this->db->get_where('er_sales', ['status' => '0', 'paid' => $status, 'customer' => $_SESSION['xfront_customer']]);
    if (!$orders->num_rows() > 0) return [];
    return $orders->result_array();
  }

  function _get_order_items()
  {
    $this->db->group_by('item');
    $items = $this->db->get_where('er_sales', ['customer' => $_SESSION['xfront_customer']]);
    if (!$items->num_rows() > 0) return [];
    $data = [];
    foreach ($items->result_array() as $row) {
      $data[$row['item']] = $this->_get_item($row['item']);
    }
    return $data;
  }

  function _get_payments()
  {
    $this->db->order_by('created_at DESC');
    $orders = $this->db->get_where('er_payments', ['status' => '0', 'payer_id' => $_SESSION['xfront_customer']]);
    if (!$orders->num_rows() > 0) return [];
    return $orders->result_array();
  }

  function _get_debt()
  {
    $this->db->select('SUM(total + shipping_fee) AS total');
    $orders = $this->db->get_where('er_sales_extra', ['status' => '0', 'customer' => $_SESSION['xfront_customer']]);
    if (!$orders->num_rows() > 0) return 0;

    $this->db->select('SUM(amount) AS payment');
    $pays = $this->db->get_where('er_payments', ['status' => '0', 'payer_id' => $_SESSION['xfront_customer']]);
    if (!$pays->num_rows() > 0) return $orders->row('total');
    return $orders->row('total') - $pays->row('payment');
  }

  function _get_inbox()
  {
    $this->db->order_by('created_at DESC');
    $notes = $this->db->get_where('er_support', ['status' => 0, 'opened' => 1,  'user' => $_SESSION['xfront_customer']]);
    if ($notes->num_rows() < 0) return [];
    return $notes->result_array();
  }

  function _get_last()
  {
    $debt = $this->_get_debt();
    if ($debt <= 0) return false;
    $pending = $this->db->get_where('er_payments', ['status' => 0, 'paid' => 0, 'payer_id' => $_SESSION['xfront_customer']]);
    if ($pending->num_rows() > 0) return 'WAHALA!';
    $this->db->order_by('created_at DESC');
    $sale = $this->db->get_where('er_sales', ['status' => 0, 'customer' => $_SESSION['xfront_customer']]);
    if ($sale->num_rows() > 0) return ['voucher' => $sale->row('voucher'), 'total' => $debt];
    return false;
  }

  function _put($data)
  {
    $this->db->where('token', $_SESSION['xfront_customer']);
    $update = $this->db->update('er_customers', $data);
    if (!$update) return false;
    return true;
  }

  function _update_count($action)
  {
    $count = $this->db->get_where('er_customers', ['status' => 0,  'token' => $_SESSION['xfront_customer']]);
    if ($count->num_rows() < 0) return false;
    $address_count =  $count->row('address_count');
    $this->db->where('token', $_SESSION['xfront_customer']);
    if ($action == 'add') {
      $update = $this->db->update('er_customers', ['address_count' => $address_count + 1]);
    } else {
      $update = $this->db->update('er_customers', ['address_count' => $address_count - 1]);
    }

    if (!$update) {
      return false;
    }
  }

  function _put_address($token, $data)
  {
    $this->db->where('token', $token);
    $this->db->where('user', $_SESSION['xfront_customer']);

    $update = $this->db->update('er_addresses', $data);

    if (!$update) {
      return false;
    }
    return true;
  }

  function _new_address($data)
  {
    $hash = base64_encode(random_bytes(32) . date('Hisa'));
    $hash = strtr($hash, '+/', '-_');
    $hash = rtrim($hash, '=');
    $data['token'] = $hash;
    $data['user'] = $_SESSION['xfront_customer'];
    if (!$this->db->insert('er_addresses', $data)) return false;
    $this->_update_count('add');
    return $data['token'];
  }

  function _drop_address($target)
  {
    $this->db->where('token', $target);
    $this->db->update('er_addresses', ['status' => '1']);
    $this->_update_count('sub');
  }

  function _get_country()
  {
    $this->db->where('status', 0);
    $setting = $this->db->get_where('er_settings', ['name' => 'country']);
    if (! ($setting->num_rows() > 0)) return false;
    return $setting->row('value');
  }

  function _get_currency()
  {
    $this->db->where('status', 0);
    $setting = $this->db->get_where('er_settings', ['name' => 'currency']);
    if (! ($setting->num_rows() > 0)) return false;
    return $setting->row('value');
  }

  function _get_region($country)
  {
    $this->db->where('status', 0);
    if ($country == 'Nigeria') {
      $region = $this->db->get_where('er_nigeria_state');
    } else {
      $region = $this->db->get_where('er_england_regions');
    }
    if ($region->num_rows() < 0) return [];
    return $region->result_array();
  }

  function _post($data)
  {
    $hash = base64_encode(random_bytes(32) . date('Hisa'));
    $hash = strtr($hash, '+/', '-_');
    $hash = rtrim($hash, '=');
    $data['token'] = $hash;
    if (!$this->db->insert('er_support', $data)) return false;
    return $data['token'];
  }

  function _post_payment($data)
  {
    $data['token'] = hash('sha256', 'pay' . time() . random_bytes(16));
    if (!$this->db->insert('er_payments', $data)) return false;
    return $data['token'];
  }

  function _drop($target)
  {
    $this->db->where('token', $target);
    $this->db->update('er_support', ['status' => '1']);
  }
}
