<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Cart_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();
  }

  function _get_price($item, $state)
  {
    $items = $this->db->get_where('er_online_warehouse', ['token' => $item]);
    if (!($items->num_rows() > 0)) return 0;
    $price = json_decode($items->row('price'), true);
    return $price[$state];
  }

  function _get_item($token)
  {
    $item = $this->db->get_where('er_online_warehouse', ['status' => 0, 'token' => $token]);
    if (!$item) return false;
    return $item->row();
  }

  function _get_sale($data)
  {
    $this->db->where($data);
    $sale = $this->db->get_where('er_sales', ['status' => 0]);
    if (!$sale) return false;
    return $sale->row_array();
  }

  function _get_cart()
  {
    $this->db->where("`date` IS NULL");
    $sales = $this->db->get_where('er_sales', ['status' => 0, 'customer' => ($_SESSION['xfront_customer'] ?? '')]);
    if (!$sales) return false;
    return $sales->result_array();
  }

  function _get_shipping($voucher)
  {
    $shipping = $this->db->get_where('er_sales_extra', ['status' => 0, 'voucher' => $voucher, 'customer' => $_SESSION['xfront_customer']]);
    if (!$shipping) return false;
    return $shipping->row_array();
  }

  function _get_payment()
  {
    $payment = $this->db->get_where('er_payments', ['status' => 0, 'paid' => 0, 'payer_id' => $_SESSION['xfront_customer']]);
    if (!$payment) return false;
    return $payment->row_array();
  }

  function _get_user()
  {
    if (!isset($_SESSION['xfront_customer'])) return [];
    $user = $this->db->get_where('er_customers', ['token' => $_SESSION['xfront_customer']]);
    if (!$user->num_rows() > 0) return [];
    return $user->row_array();
  }

  function _get_suggestions($item)
  {
    $token    = $item->token ?? '';
    $category = $item->category ?? '';

    if ($item) $this->db->where('category', $category);
    $this->db->order_by("'NEWID() DESC'")->limit(6);
    $relatives = $this->db->get_where('er_online_warehouse', ['status' => 0, 'token !=' => $token]);
    if (!$relatives->num_rows() > 0) return [];

    return $relatives->result_array();
  }

  function _get_name($table, $token)
  {
    $data = $this->db->get_where('er_' . $table, ['token' => $token]);
    if (!$data->num_rows() > 0) return [];

    return $data->row('name');
  }

  function _get_categories()
  {
    $this->db->order_by('name');
    $data = $this->db->get_where('er_categories', ['status' => 0, 'parent' => '']);
    if (!$data->num_rows() > 0) return [];

    $file = [];
    foreach ($data->result_array() as $row) {
      $this->db->order_by('name');
      $subs = $this->db->get_where('er_categories', ['status' => 0, 'parent' => $row['token']]);
      $row['children'] = $subs->result_array() ?? [];

      $file[] = $row;
    }

    return $file;
  }

  function _get_shipping_fee($param)
  {
    $this->db->where('status', 0);
    $setting = $this->db->get_where('er_shipping_settings', ['region' => $param]);
    if (! ($setting->num_rows() > 0)) {
      $setting = $this->db->get_where('er_shipping_settings', ['region' => 'General']);
    } else return false;
    return $setting->row('fee');
  }

  function _get_market()
  {
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }

  function _get_voucher()
  {
    $this->db->where("`date IS NULL");
    $check = $this->db->get_where('er_sales', ['status' => 0, 'customer' => $_SESSION['xfront_customer']]);
    if ($check->num_rows() > 0) return $check->row('voucher');

    $this->db->group_by('voucher');
    $last = $this->db->count_all_results('er_sales') + 1001;
    $last = str_repeat('0', 7 - strlen($last)) . $last;
    return $last;
  }

  function _get_pending()
  {
    $pay = $this->db->get_where('er_payments', ['payer_id' => $_SESSION['xfront_customer'], 'status' => 0, 'paid' => 0, 'pay_ref !=' => '']);
    if ($pay->num_rows() > 0) return true;
  }

  function _post($data)
  {
    $hash = base64_encode(random_bytes(16) . date('Hisa'));
    $hash = strtr($hash, '+/', '-_');
    $hash = rtrim($hash, '=');
    $data['token'] = $hash;
    if (!$this->db->insert('er_sales', $data)) return false;
    return $data['token'];
  }

  function _post_shipping($data)
  {
    $data['token'] = hash('sha256', 'ship' . time() . random_bytes(16));
    if (!$this->db->insert('er_sales_extra', $data)) return false;
    return $data['token'];
  }

  function _put_shipping($data, $chip)
  {
    $this->db->where('token', $chip);
    if (!$this->db->update('er_sales_extra', $data)) return false;
    return true;
  }

  function _post_payment($data)
  {
    $data['token'] = hash('sha256', 'pay' . time() . random_bytes(16));
    if (!$this->db->insert('er_payments', $data)) return false;
    return $data['token'];
  }

  function _put_payment($data, $chip)
  {
    $this->db->where('token', $chip);
    if (!$this->db->update('er_payments', $data)) return false;
    return true;
  }

  function _post_many($data)
  {
    if (!$this->db->insert_batch('er_sales', $data)) return false;
    return true;
  }

  function _put_many($chip, $data)
  {
    if (!$this->db->update_batch('er_sales', $data, $chip)) return false;
    return true;
  }

  function _add_item($token)
  {
    if (isset($_SESSION['xfront_customer'])) {
      $this->db->where(['item' => $token, 'customer' => $_SESSION['xfront_customer'], 'status' => '1']);
      $this->db->update('er_sales', ['status' => 0]);
    }
    return true;
  }

  function _drop_item($token)
  {
    if (isset($_SESSION['xfront_customer'])) {
      $this->db->where("`date` IS NULL");
      $this->db->where(['item' => $token, 'customer' => $_SESSION['xfront_customer']]);
      $this->db->update('er_sales', ['status' => 1]);
    }
    return true;
  }
}
