<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Index_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();
  }

  function _get_vars()
  {
    $settings = $this->db->get_where('er_settings', ['status' => 0]);
    if (!$settings->num_rows() > 0) return [];

    $data = [];
    foreach ($settings->result_array() as $row)
      $data[$row['name']] = $row['value'];

    return $data;
  }

  function _get_item($token, $select = '')
  {
    if ($select != '') $this->db->select($select);
    $item = $this->db->get_where('er_online_warehouse', ['status' => 0, 'token' => $token]);
    if (!$item->num_rows() > 0) return false;
    if ($select != '') return $item->row_array();
    return $item->row();
  }

  function _get_itemy($token)
  {
    $this->db->select('item, price, quantity, voucher, waybill, paid');
    $item = $this->db->get_where('er_sales', ['status' => 0, 'token' => $token]);
    if (!$item->num_rows() > 0) return [];
    $data = $item->row_array();
    $data = array_merge($data, $this->_get_item($data['item'], 'name, image'));
    return $data;
  }

  function _get_itemx($cart_id)
  {
    $sales = $this->db->get_where('er_sales', ['status' => 0, 'voucher' => $cart_id]);
    if (!$sales->num_rows() > 0) return [];

    $items = [];
    foreach ($sales->result_array() as $row) {
      $item = $this->_get_item($row['item']);
      $row['name'] = $item->name ?? '';
      $row['image'] = $item->image ?? '';

      $items[] = $row;
    }

    return $items;
  }

  function _get_cart($token)
  {
    $this->db->select('item, price, quantity, voucher, paid');
    $item = $this->db->get_where('er_sales', ['status' => 0, 'voucher' => $token]);
    if (!$item->num_rows() > 0) return [];
    $data = $item->result_array();
    foreach ($data as $key => $val) {
      $data[$key] = array_merge($data[$key], $this->_get_item($val['item'], 'name, image'));
    }
    return $data;
  }

  function _get_name($table, $token)
  {
    $data = $this->db->get_where('er_' . $table, ['token' => $token]);
    if (!$data->num_rows() > 0) return [];

    return $data->row('name');
  }

  function _get_user()
  {
    if (!isset($_SESSION['xfront_customer'])) return [];
    $user = $this->db->get_where('er_customers', ['token' => $_SESSION['xfront_customer']]);
    if (!$user->num_rows() > 0) return [];
    return $user->row_array();
  }

  function _get_categories()
  {
    $this->db->order_by('name');
    $data = $this->db->get_where('er_categories', ['status' => 0, 'parent' => '']);
    if (!$data->num_rows() > 0) return [];

    $file = [];
    foreach ($data->result_array() as $row) {
      $this->db->order_by('name');
      $subs = $this->db->get_where('er_categories', ['status' => 0, 'parent' => $row['token']]);
      $row['children'] = $subs->result_array() ?? [];

      $file[] = $row;
    }

    return $file;
  }

  function _get_market_categories($like)
  {
    $this->db->like('name', $like);
    $this->db->order_by('name');
    $data = $this->db->get_where('er_categories', ['status' => 0]);
    if (!$data->num_rows() > 0) return [];

    return $data->result_array();
  }

  function _get_market($limit = 0)
  {
    $extract = "CAST(JSON_EXTRACT(`price`, '$.a577f519b58b533e400cf28a7464576babf92121[0]') AS DECIMAL(10,1))";
    $this->db->select("*, $extract AS price");
    if (isset($_SESSION['xfront_filter_min']))
      $this->db->where("$extract >=", $_SESSION['xfront_filter_min']);
    if (isset($_SESSION['xfront_filter_max']))
      $this->db->where("$extract <=", $_SESSION['xfront_filter_max']);
    if (isset($_SESSION['xfront_filter_sort'])) {
      $sort = $_SESSION['xfront_filter_sort'];
      if ($sort == 'newest') $this->db->order_by('created_at DESC');
      if ($sort == 'lowest') $this->db->order_by('price ASC');
      if ($sort == 'highest') $this->db->order_by('price DESC');
    }

    if ($limit !== 0) $this->db->limit($limit);
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }


  function _get_currency()
  {
    $this->db->where('status', 0);
    $setting = $this->db->get_where('er_settings', ['name' => 'currency']);
    if (! ($setting->num_rows() > 0)) return false;
    return $setting->row('value');
  }

  function _get_latest()
  {
    $this->db->order_by('stock_date')->limit(12);
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }

  function _get_popular()
  {
    $this->db->order_by('sold DESC')->limit(12);
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }

  function _get_discounted()
  {
    $this->db->order_by('discount DESC')->limit(12);
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0, 'discount >' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }

  function _get_random()
  {
    $this->db->order_by('RAND()')->limit(12);
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return [];

    return $items->result_array();
  }

  function _get_sum($table, $col, $filter = '')
  {
    $this->db->select_sum($col);
    return $this->db->get_where($table, $filter)->row($col);
  }

  function _get_sale($cart)
  {
    $sale = $this->db->get_where('er_sales', ['status' => 0, 'customer' => $_SESSION['xfront_customer'], 'voucher' => $cart]);
    if (!$sale->num_rows() > 0) return [];
    return $sale->row_array();
  }

  function _get_inbox()
  {
    $where = ['status' => 0, 'notifier_token' => $_SESSION['xfront_customer'], 'type' => 'Checkout'];
    $this->db->select('title, created_at')->order_by('created_at DESC');
    $notes = $this->db->get_where('er_notification', $where);
    if (!$notes) return [];
    $this->db->where($where);
    $this->db->update('er_notification', ['views' => $_SESSION['xfront_customer']]);
    return $notes->result_array();
  }

  function _get_notice()
  {
    $where = ['status' => 0, 'notifier_token' => $_SESSION['xfront_customer'], 'type' => 'Checkout'];
    $this->db->not_like('views', $_SESSION['xfront_customer']);
    $this->db->where($where);
    $this->db->select('title, created_at')->order_by('created_at DESC');
    $notes = $this->db->count_all_results('er_notification');
    return $notes;
  }

  function _get_delivery($cart)
  {
    $way = $this->db->get_where('er_sales', ['status' => 0, 'voucher' => $cart]);
    if (!$way->num_rows() > 0) return [];
    return $way->row_array();
  }

  function _get_shipping($cart)
  {
    $ship = $this->db->get_where('er_sales', ['status' => 0, 'voucher' => $cart]);
    if (!$ship->num_rows() > 0) return [];
    return $ship->row_array();
  }

  function _get_payments($cart)
  {
    $this->db->order_by('id');
    $this->db->select('pay_type, code_discount, SUM(amount) AS amount');
    $pay = $this->db->get_where('er_payments', ['status' => 0, 'supply_id' => $cart]);
    if (!$pay->num_rows() > 0) return [];
    return $pay->row_array();
  }
}
