<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Notification_model extends CI_Model
{

  function __construct()
  {
    parent::__construct();

    if (isset($_SESSION['xfront_customer'])) {
      $low = ($this->_stock() === true) ? 1 : 0;
      if (!isset($_SESSION['xfront_admin'])) $low = 0;
      $_SESSION['xfront_notice'] = $this->_count() + $low;
    }
  }

  function _get($params)
  {
    $this->db->where(['status' => 0]);
    $user = $this->db->get_where('er_notification', $params);
    if (!($user->num_rows() > 0)) return false;
    return $user->row();
  }

  function _get_min()
  {
    $stock = $this->db->get_where('er_settings', ['name' => 'stock_limit']);
    if (!($stock->num_rows() > 0)) return false;
    return $stock->row('value');
  }

  function _get_outlet($token)
  {
    $outlet = $this->db->get_where('er_warehouse', ['token' => $token]);
    if (!($outlet->num_rows() > 0)) return false;
    return $outlet->row();
  }

  function _get_outlets()
  {
    $outlets = $this->db->get_where('er_warehouse', ['status' => 0]);
    if (!($outlets->num_rows() > 0)) return false;

    $data = [];
    foreach ($outlets->result_array() as $row) {
      $data[$row['token']] = $row['name'];
    }
    return $data;
  }

  function _get_all()
  {
    if (!isset($_SESSION['xfront_admin'])) $this->db->where("JSON_EXTRACT(`helper`, '$.warehouse') = '" . $_SESSION['xfront_warehouse'] . "'");
    $this->db->order_by('notification_id', 'DESC')->limit(100);
    $notes = $this->db->get_where('er_notification', ['status' => 0]);
    if (!($notes->num_rows() > 0)) return false;
    return $notes->result_array();
  }

  function _get_named($table, $token, $tag = 'name')
  {
    $table = 'er_' . $table;
    $name = $this->db->get_where($table, ['token' => $token]);
    if (!($name->num_rows() > 0)) return '';
    return $name->row($tag);
  }


  function _count()
  {
    // if ( ! isset($_SESSION['xfront_admin'])) $this->db->where("JSON_EXTRACT(`helper`, '$.warehouse') = '".$_SESSION['xfront_warehouse']."'");
    $this->db->not_like('views', $this->session->userdata('xfront_customer'));
    return $this->db->count_all_results('er_notification');
  }

  function _stock()
  {
    $min = $this->_get_min();
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return false;
    foreach ($items->result_array() as $item) {
      $outlets = $this->db->group_by('outlet')->get_where('er_supply', ['status' => 0]);
      if (!$outlets->num_rows() > 0) return false;
      foreach ($outlets->result_array() as $row) {
        $this->db->where('status', 0);
        if (!$this->_get_outlet($row['outlet'])) continue;
        $this->db->select('SUM(quantity) as quantity');
        $supply = $this->db->get_where('er_supply', ['item' => $item['token'], 'outlet' => $row['outlet']])->row('quantity') ?? 1000000000000000000;
        $this->db->select('SUM(quantity) as quantity');
        $sales = $this->db->get_where('er_sales', ['type' => 0, 'item' => $item['token'], 'warehouse' => $row['outlet']])->row('quantity') ?? 0;
        $test = $supply - $sales;
        if ($test < $min) return true;
      }
    }
    return false;
  }

  function _get_stock()
  {
    $min = $this->_get_min();
    $items = $this->db->get_where('er_online_warehouse', ['status' => 0]);
    if (!$items->num_rows() > 0) return false;
    $data = [];
    foreach ($items->result_array() as $item) {
      $outlets = $this->db->group_by('outlet')->get_where('er_supply', ['status' => 0]);
      if (!$outlets->num_rows() > 0) return false;
      foreach ($outlets->result_array() as $row) {
        $this->db->select('SUM(quantity) as quantity');
        $supply = $this->db->get_where('er_supply', ['item' => $item['token'], 'outlet' => $row['outlet']])->row('quantity') ?? 1000000000000000000;
        $this->db->select('SUM(quantity) as quantity');
        $sales = $this->db->get_where('er_sales', ['type' => 0, 'item' => $item['token'], 'warehouse' => $row['outlet']])->row('quantity') ?? 0;
        $test = $supply - $sales;
        if ($test < $min) $data[] = $row['outlet'];
      }
    }
    return array_unique($data);
  }

  function _put($target)
  {
    $note = $this->db->get_where('er_notification', ['notifier_token' => $target]);
    $views = $note->row('views') ?? '';
    if (strstr($views, $_SESSION['xfront_customer']) == '') $views .= $_SESSION['xfront_customer'] . ' ';

    $this->db->where('notifier_token', $target);
    $user = $this->db->update('er_notification', ['views' => $views]);
    if (!$user) return false;
    return true;
  }

  function _post($data)
  {
    $hash = base64_encode(random_bytes(32) . date('Hisa'));
    $hash = strtr($hash, '+/', '-_');
    $hash = rtrim($hash, '=');
    $data['token'] = $hash;
    if (!$this->db->insert('er_notification', $data)) return false;
    return $data['token'];
  }

  function _drop($target)
  {
    $this->db->where('notifier_token', $target);
    $this->db->update('er_notification', ['status' => '1']);
  }
}
